@@ -1,6 +1,11 @@
 # -*- coding:utf-8 -*-
 from django.contrib import admin
 from django.contrib.admin.options import InlineModelAdmin
+from django.conf import settings
+from tinymce.widgets import AdminTinyMCE
+from django import forms
+from sorl.thumbnail.admin import AdminImageMixin
+from django.utils.translation import ugettext_lazy as _
 
 
 class ObjEnabledInline(InlineModelAdmin):
@@ -25,6 +30,56 @@ class ObjEnabledAdmin(admin.ModelAdmin):  # TODO bring back the permissions code
             request, obj, **kwargs)
 
 
+if "coop_cms" in settings.INSTALLED_APPS:
+
+    from coop_cms.admin import NavTreeAdmin, ArticleAdmin
+    from coop_cms.models import NavTree
+    from coop_cms.settings import get_article_class
+    from coop_cms.forms import ArticleAdminForm   
+
+    # -- We need to customize coop-cms NavtreeAdmin
+
+    class MyNavTreeAdmin(NavTreeAdmin):
+        change_form_template = 'admin/navtree_change_form.html' 
+
+    admin.site.unregister(NavTree)
+    admin.site.register(NavTree, MyNavTreeAdmin)
+
+    # -- We need to customize coop-cms ArticleAdmin
+
+    class CoopArticleForm(ArticleAdminForm):
+        content = forms.CharField(widget=AdminTinyMCE(attrs={'cols': 80, 'rows': 60}), required=False)
+
+    class CoopArticleAdmin(ArticleAdmin, AdminImageMixin):
+        form = CoopArticleForm
+        change_form_template = 'admintools_bootstrap/tabbed_change_form.html' 
+        change_list_template = 'admin/article_change_list.html'
+
+        list_display = ['logo_list_display', 'title', 'publication', 'section', 'modified', 'in_newsletter']
+        list_editable = ['publication', 'in_newsletter', 'section']
+        list_display_links = ['title']
+
+        readonly_fields = ['created', 'modified']
+        fieldsets = (
+            #(_('Navigation'), {'fields': ('navigation_parent',)}),
+            ('Edition', {'fields': ('title', 'logo', 'content', 'template')}),
+            ('Options', {'fields': ('summary', 'section', 'is_homepage', 'in_newsletter')}),
+        )
+        
+        def get_form(self, request, obj=None, **kwargs):
+            form = super(ArticleAdmin, self).get_form(request, obj, **kwargs)
+            form.current_user = request.user
+            return form
+
+    admin.site.unregister(get_article_class())
+    admin.site.register(get_article_class(), CoopArticleAdmin)
+
+
+
+
+
+
+
 
 #     def get_inline_instances(self, request, obj):
 #         inline_instances = []
