@@ -8,8 +8,8 @@ from djaloha.widgets import AlohaInput
 class ArticleForm(CmsArticleForm):
     class Meta:
         model = get_article_class()
-        fields = ('title', 'content', 'logo', 'author')
+        fields = ('title', 'content', 'logo')
         widgets = {
-            'title': AlohaInput(),
-            'content': AlohaInput(),
+            'title': AlohaInput(text_color_plugin=False),
+            'content': AlohaInput(text_color_plugin=False),
         }
\ No newline at end of file
