@@ -6,11 +6,12 @@ from django.utils.translation import ugettext_lazy as _
 from django.core.urlresolvers import reverse
 from django.contrib.contenttypes import generic
 from django.contrib.contenttypes.models import ContentType
-import sorl
 from django.core.exceptions import ValidationError
 from django.conf import settings
 from coop.models import URIModel
-
+from sorl.thumbnail import ImageField
+from sorl.thumbnail import default
+ADMIN_THUMBS_SIZE = '60x60' 
 
 
 DISPLAY = Choices(
@@ -184,7 +185,9 @@ class BaseOrganization(URIModel):
                 help_text=_(u'tell us what your organization do in one line.'))
 
     description = models.TextField(_(u'description'), blank=True, null=True)
-    logo = sorl.thumbnail.ImageField(upload_to='logos/', null=True, blank=True)
+
+    logo = ImageField(upload_to='logos/', null=True, blank=True)
+
     relations = models.ManyToManyField('coop_local.Organization', 
                 symmetrical=False, through='coop_local.Relation', 
                 verbose_name=_(u'relations'))
@@ -256,12 +259,20 @@ class BaseOrganization(URIModel):
             from coop_geo.models import Area
             return Area.objects.filter(id__in=self.framed.all().values_list('location_id', flat=True))
 
-
     def has_description(self):
         return self.description != None and len(self.description) > 20
     has_description.boolean = True    
     has_description.short_description = _(u'desc.')
 
+    def logo_list_display(self):
+        if self.logo:
+            thumb = default.backend.get_thumbnail(self.logo.file, ADMIN_THUMBS_SIZE)
+            return '<img width="%s" src="%s" />' % (thumb.width, thumb.url)
+        else:
+            return _(u"No Image") 
+    logo_list_display.short_description = _(u"logo")
+    logo_list_display.allow_tags = True   
+
     #@models.permalink
     def get_absolute_url(self):
         return reverse('org_detail', args=[self.slug])
